from typing import Any

from opentracing import Span

class MockSpan(Span):
    operation_name: str
    start_time: Any
    parent_id: Any
    tags: Any
    finish_time: int
    finished: bool
    logs: Any
    def __init__(self, tracer, operation_name=..., context=..., parent_id=..., tags=..., start_time=...) -> None: ...
    def set_operation_name(self, operation_name: str): ...
    def set_tag(self, key, value): ...
    def log_kv(self, key_values, timestamp=...): ...
    def finish(self, finish_time=...) -> None: ...
    def set_baggage_item(self, key, value): ...
    def get_baggage_item(self, key): ...

class LogData:
    key_values: Any
    timestamp: Any
    def __init__(self, key_values, timestamp=...) -> None: ...



from ..scope_manager import ScopeManager
from ..span import Span

class ContextVarsScopeManager(ScopeManager):
    def activate(self, span: Span, finish_on_close: bool): ...
    @property
    def active(self): ...

def no_parent_scope() -> None: ...



from ..scope_manager import ScopeManager
from ..span import SpanContext
from ..tracer import Tracer
from .propagator import Propagator

class MockTracer(Tracer):
    def __init__(self, scope_manager: ScopeManager | None = ...) -> None: ...
    def register_propagator(self, format, propagator: Propagator) -> None: ...
    def finished_spans(self): ...
    def reset(self) -> None: ...
    def start_active_span(
        self,
        operation_name,
        child_of=...,
        references=...,
        tags=...,
        start_time=...,
        ignore_active_span: bool = ...,
        finish_on_close: bool = ...,
    ): ...
    def start_span(
        self, operation_name=..., child_of=..., references=..., tags=..., start_time=..., ignore_active_span: bool = ...
    ): ...
    def inject(self, span_context: SpanContext, format, carrier) -> None: ...
    def extract(self, format, carrier): ...



from opentracing.span import Span

from ..tracer import Tracer

class APICompatibilityCheckMixin:
    def tracer(self) -> Tracer: ...
    def check_baggage_values(self) -> bool: ...
    def check_scope_manager(self) -> bool: ...
    def is_parent(self, parent, span: Span) -> bool: ...
    def test_active_span(self) -> None: ...
    def test_start_active_span(self) -> None: ...
    def test_start_active_span_parent(self) -> None: ...
    def test_start_active_span_ignore_active_span(self) -> None: ...
    def test_start_active_span_not_finish_on_close(self) -> None: ...
    def test_start_active_span_finish_on_close(self) -> None: ...
    def test_start_active_span_default_finish_on_close(self) -> None: ...
    def test_start_span(self) -> None: ...
    def test_start_span_propagation(self) -> None: ...
    def test_start_span_propagation_ignore_active_span(self) -> None: ...
    def test_start_span_with_parent(self) -> None: ...
    def test_start_child_span(self) -> None: ...
    def test_set_operation_name(self) -> None: ...
    def test_span_as_context_manager(self) -> None: ...
    def test_span_tag_value_types(self) -> None: ...
    def test_span_tags_with_chaining(self) -> None: ...
    def test_span_logs(self) -> None: ...
    def test_span_baggage(self) -> None: ...
    def test_context_baggage(self) -> None: ...
    def test_text_propagation(self) -> None: ...
    def test_binary_propagation(self) -> None: ...
    def test_mandatory_formats(self) -> None: ...
    def test_unknown_format(self) -> None: ...
    def test_tracer_start_active_span_scope(self) -> None: ...
    def test_tracer_start_span_scope(self) -> None: ...



from .span import Span

class Scope:
    def __init__(self, manager, span: Span) -> None: ...
    @property
    def span(self): ...
    @property
    def manager(self): ...
    def close(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type, exc_val, exc_tb) -> None: ...



from typing import Any

import opentracing

class SpanContext(opentracing.SpanContext):
    trace_id: Any
    span_id: Any
    def __init__(self, trace_id=..., span_id=..., baggage=...) -> None: ...
    @property
    def baggage(self): ...
    def with_baggage_item(self, key, value): ...



from ..span import SpanContext
from .propagator import Propagator

class BinaryPropagator(Propagator):
    def inject(self, span_context: SpanContext, carrier) -> None: ...
    def extract(self, carrier): ...



from .scope_manager import ScopeManager
from .span import Span, SpanContext

class Tracer:
    def __init__(self, scope_manager: ScopeManager | None = ...) -> None: ...
    @property
    def scope_manager(self) -> ScopeManager: ...
    @property
    def active_span(self) -> Span: ...
    def start_active_span(
        self,
        operation_name: str,
        child_of=...,
        references=...,
        tags=...,
        start_time=...,
        ignore_active_span: bool = ...,
        finish_on_close: bool = ...,
    ): ...
    def start_span(
        self,
        operation_name: str | None = ...,
        child_of=...,
        references=...,
        tags=...,
        start_time=...,
        ignore_active_span: bool = ...,
    ): ...
    def inject(self, span_context: SpanContext, format, carrier) -> None: ...
    def extract(self, format, carrier): ...

class ReferenceType:
    CHILD_OF: str
    FOLLOWS_FROM: str

class Reference: ...

def child_of(referenced_context=...): ...
def follows_from(referenced_context=...): ...
def start_child_span(parent_span: Span, operation_name: str, tags=..., start_time=...): ...



from typing import Any

from ..scope_managers import ThreadLocalScopeManager
from ..span import Span

class TornadoScopeManager(ThreadLocalScopeManager):
    def activate(self, span: Span, finish_on_close: bool): ...
    @property
    def active(self): ...

class ThreadSafeStackContext:
    contexts: Any
    def __init__(self, *args) -> None: ...

def tracer_stack_context(): ...



from ..scope_managers import ThreadLocalScopeManager
from ..span import Span

class AsyncioScopeManager(ThreadLocalScopeManager):
    def activate(self, span: Span, finish_on_close: bool): ...
    @property
    def active(self): ...



from typing import Any

from .tracer import Tracer

class SpanContext:
    EMPTY_BAGGAGE: Any
    @property
    def baggage(self): ...

class Span:
    def __init__(self, tracer: Tracer, context: SpanContext) -> None: ...
    @property
    def context(self): ...
    @property
    def tracer(self) -> Tracer: ...
    def set_operation_name(self, operation_name: str): ...
    def finish(self, finish_time=...) -> None: ...
    def set_tag(self, key, value): ...
    def log_kv(self, key_values, timestamp=...): ...
    def set_baggage_item(self, key, value): ...
    def get_baggage_item(self, key) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type, exc_val, exc_tb) -> None: ...
    def log_event(self, event, payload=...): ...
    def log(self, **kwargs): ...



from ..scope_manager import ScopeManager
from ..span import Span

class ThreadLocalScopeManager(ScopeManager):
    def __init__(self) -> None: ...
    def activate(self, span: Span, finish_on_close: bool): ...
    @property
    def active(self): ...



from setuptools import setup

name = "types-opentracing"
description = "Typing stubs for opentracing"
long_description = '''
## Typing stubs for opentracing

This is a PEP 561 type stub package for the `opentracing` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `opentracing`. The source for this package can be found at
https://github.com/python/typeshed/tree/master/stubs/opentracing. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/master/README.md for more details.
This package was generated from typeshed commit `906d5f1fafe644cfd9cb459496e45624f6429768`.
'''.lstrip()

setup(name=name,
      version="2.4.0",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      install_requires=[],
      packages=['opentracing-stubs'],
      package_data={'opentracing-stubs': ['__init__.pyi', 'ext/__init__.pyi', 'ext/tags.pyi', 'harness/__init__.pyi', 'harness/api_check.pyi', 'harness/scope_check.pyi', 'logs.pyi', 'mocktracer/__init__.pyi', 'mocktracer/binary_propagator.pyi', 'mocktracer/context.pyi', 'mocktracer/propagator.pyi', 'mocktracer/span.pyi', 'mocktracer/text_propagator.pyi', 'mocktracer/tracer.pyi', 'propagation.pyi', 'scope.pyi', 'scope_manager.pyi', 'scope_managers/__init__.pyi', 'scope_managers/asyncio.pyi', 'scope_managers/constants.pyi', 'scope_managers/contextvars.pyi', 'scope_managers/gevent.pyi', 'scope_managers/tornado.pyi', 'span.pyi', 'tags.pyi', 'tracer.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Typing :: Typed",
      ]
)



class ScopeCompatibilityCheckMixin:
    def scope_manager(self) -> None: ...
    def run_test(self, test_fn) -> None: ...
    def test_missing_active_external(self) -> None: ...
    def test_missing_active(self) -> None: ...
    def test_activate(self) -> None: ...
    def test_activate_external(self) -> None: ...
    def test_activate_finish_on_close(self) -> None: ...
    def test_activate_nested(self) -> None: ...
    def test_activate_finish_on_close_nested(self) -> None: ...
    def test_close_wrong_order(self) -> None: ...
